Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

Earth-Ref Magic Builder Help Window

The ErMagicBuilder is a Python tool for adding Earth-Ref data to MagIC project.
The top row in the dialog window shows the headers of the Earth-Ref tables. The required headers are added and cannot be removed. The bottom row in the dialog window shows a list of optional headers.
(Details on MagIC model different headers are in: `"http://earthref.org/MagIC/metadata/`)
To add or remove headers from your project model: choose the header name and click the add/remove buttons.

After you choose the headers of the tables press the OK button and follow the following steps in order:

1. Open er_specimens.txt with Excel.
   - Check sample name for each specimen (under the header er_sample_name). Add or correct if necessary.
   - Save and close the file. If any changes has made: Re-run Earth-Ref Magic Builder and press OK. (the OK button propagates the information to all levels)

2. Open er_samples.txt with Excel.
   - Check site names for each sample (under the header er_site_name). Add or correct if necessary.
   - Save and close the file. If any changes has made: Re-run Earth-Ref Magic Builder and press OK. (the OK button propagates the information to all levels)

3. Open er_sites.txt with Excel.
   - Check location name (under the header er_location_name).
   - Fill site class (under the header site_class).
     Use controlled vocabularies from: `site class controlled vocabularies`
   - Fill site lithology (under the header site_lithology).
     Use controlled vocabularies from `site lithology controlled vocabularies`. If you cant find any appropriate definition use: Not Specified.
   - Fill site type (under the header site_type).
     Use controlled vocabularies from `site type controlled vocabularies`. If you cant find any appropriate definition use: Not Specified.
   - Fill site definition (under the header site_definition: the letter "s" for single site or the letter "c" for composite site (including various units).
   - Fill site longitude (under the header site_lon):Decimal degrees between 0 and 360.
   - Fill site latitude (under the header site_lat): Decimal degrees between -90 and 90
   - Save and close the file. Re-run Earth-Ref Magic Builder and press OK.

4. Open er_samples.txt with Excel. some of the data you entered in er_sites.txt is now propagated into er_samples.txt. Fill in manually the rest of the information:
   - Check sample class (under the header sample_class).
     If you need to change it because site class is different from sample class: use controlled vocabularies from `sample class controlled vocabularies`.
   - Check sample lithology (under the header sample_lithology).
     If you need to change it because site lithology is different from sample lithology: use controlled vocabularies from `sample lithology controlled vocabularies`. If you cant find any appropriate definition use: Not Specified.
   - Check sample type (under the header sample_type).
     If you need to change it because site type is different from sample type: use controlled vocabularies from `sample type controlled vocabularies`. If you cant find any appropriate definition use: Not Specified.
   - If any changes has made: Save and close the file. Re-run Earth-Ref Magic Builder and press OK.

5. Open er_locations.txt with Excel.
   - Fill location type (under the header location_type).
     Use controlled vocabularies from `location type controlled vocabularies`. If you cant find any appropriate definition use: Not Specified.
   - Save and close the file. Re-run Earth-Ref Magic Builder and press OK.

6. Now we need to add ages. You can specify ages to any level (specimen, sample, site, location). But it is most recommended to assign ages to sites.
   - Open the Earth-Ref Magic Builder and see that er_site_name is already assigned as a header in er_ages.txt by default.
     Manually add your choices of headers (for example: age, age_sigma or age, age_range_low ,age_range_high) and press OK.
     For explanation in the different headers see: `er_ages Table`
   - Open er_ages.txt with Excel. Insert age information under the appropriate headers.
     For Example:
     - Fill age units (under the header age_unit).
       Use controlled vocabularies from `age unit controlled vocabularies`.
     - Fill age (under the header age).
     - Fill age_range_low (under the header age_range_low).
     - Fill age_range_high (under the header age_range_high).
     - Fill age_description (under the header age_description): any text line.
     Fill geochronology method specifying dating technique (under the header magic_method_codes).
     Use controlled vocabularies from `Geochronology Method codes`.
   - Save and close the file.